 import { 
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  area,
  curveBasis
} from 'd3';   

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = (data) => { 
  const graphTitle = 'Exchange  rate in last week'
  const circleRadius = 5
  const yValue = d => d.exchange
  const yAxisLabel = 'Exchange-Rates'
  const xValue = d => d.date
  const xAxisLabel = 'Date'
  const margin = {top: 80, right: 60, bottom: 40, left: 120};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.left - margin.right;
  
  const xScale = scaleTime()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
          
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
  	.range([innerHeight, 0])  
  	.nice()

	const g = svg.append('g')
  	.attr(`transform`, `translate(${margin.left}, ${margin.top})`); 
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(20)
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
    .tickPadding(5)
  
  const yAxisG = g.append('g')
    .call(yAxis);
  
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('x', -innerHeight / 2)
  	.attr('y', -60)
    .attr('transform', 'rotate(-90)')
  	.attr('fill', 'black')
  	.attr('text-anchor','middle')
  	.text(yAxisLabel)
  
  const xAxisG = g.append('g').call(xAxis)  	
    .attr(`transform`, `translate(0, ${innerHeight})`);
  
  xAxisG.selectAll('.domain').remove();

  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('x', innerWidth / 2)
  	.attr('y', 75)
  	.attr('fill', 'black')
  	.text(xAxisLabel)
  
  const areaGenerator = area()
  	.x(d => xScale(xValue(d)))
  	.y0(innerHeight)
  	.y1(d => yScale(yValue(d)))
  .curve(curveBasis)
  
  g.append('path')
  	.attr('class', 'line-path') 
  	.attr('d', areaGenerator(data));
  
  g.append('text')
  	.attr('y', -20)
  	.text(graphTitle)
}

// Loads in data
csv('https://gist.githubusercontent.com/Saahithi49/d616dffe37d91d53ddec1b4843cc2127/raw/62d7c6fba0aa94cd6d47e091e09806ab61d497d6/ex.csv')
	.then((data) => {
	data.forEach(d => {
  	d.date = new Date(d.date) 
  	d.exchange = +d.exchange
  })
  render(data)
 });
